Documentation
¶
Overview ¶
Package hub exposes sup actors, controls, signals, and events over HTTP.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Hub ¶
Hub exposes actors, controls, signals, and events over HTTP.
func (*Hub) Handler ¶ added in v0.0.52
Handler returns the HTTP handler for the hub API and debug UI.
func (*Hub) Observer ¶ added in v0.0.52
func (h *Hub) Observer() *sup.SupervisorObserver
Observer returns a supervisor observer that records actor lifecycle events.
func (*Hub) RegisterActor ¶ added in v0.0.52
RegisterActor registers an actor with the hub.
type Option ¶ added in v0.0.52
type Option func(*Hub)
Option configures a Hub.
func WithEventLimit ¶ added in v0.0.52
WithEventLimit sets the maximum number of events stored per source.
func WithSignal ¶ added in v0.0.52
func WithSignal[V any](signal sup.ReadableSignal[V]) Option
WithSignal registers a readable signal with the hub.
Click to show internal directories.
Click to hide internal directories.